package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Jun 16, 2024
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type SendMessageReqBody struct {
ChatID int64 `json:"chat_id"`
Text string `json:"text"`
}
type SendPhotoReqBody struct {
ChatID int64 `json:"chat_id"`
Photo string `json:"photo"`
}
type WebhookReqBody struct {
Message struct {
Text string `json:"text"`
Chat struct {
ID int64 `json:"id"`
} `json:"chat"`
} `json:"message"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.